<?php
/**
 * @file
 * Admin settings page and checked nodes summary table.
 */

function disable_breadcrumbs_settings_page() {
  $output = drupal_get_form('disable_breadcrumbs_settings_form');
  return $output;
}

/**
 * Settings/configuration form.
 */
function disable_breadcrumbs_settings_form() {
  $content_types = array_map('check_plain', node_type_get_names());

  $form['node_types'] = array(
    '#type' => 'fieldset',
    '#title' => t('Content type settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['node_types']['disable_breadcrumbs_node_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content types breadcrumbs can be disabled on'),
    '#options' => $content_types,
    '#default_value' => variable_get('disable_breadcrumbs_node_types', array()),
    '#multiple' => TRUE,
  );
  $form['node_types']['disable_breadcrumbs_node_types_all'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content types to disable all breadcrumbs for'),
    '#options' => $content_types,
    '#default_value' => variable_get('disable_breadcrumbs_node_types_all', array()),
    '#multiple' => TRUE,
  );
  $form['reset_breadcrumbs'] = array(
    '#type' => 'fieldset',
  );
  $form['reset_breadcrumbs']['button'] = array(
    '#type' => 'submit',
    '#value' => t("Reset breadcrumbs"),
    '#prefix' => '<div id="reset-breadcrumbs">',
    '#suffix' => '</div>',
    '#submit' => array('disable_breadcrumbs_settings_form_delete_all_submit'),
    '#attributes' => array(
      'id' => 'reset-breadcrumbs',
      'onclick' => 'return confirm("Are you sure you want to clear the disable_breadcrumbs database table? This cannot be undone.")',
    ),
  );
  $form['reset_breadcrumbs']['markup'] = array(
    '#markup' => '<em>' . t('reset disable breadcrumbs database table - disabled breadcrumb settings on all nodes will be removed.') . '</em>',
  );
  $form['checked_nodes'] = array(
    '#type' => 'fieldset',
    '#title' => t('Currently checked nodes'),
    '#weight' => 100,
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['checked_nodes']['table'] = array(
    '#markup' => theme('disable_breadcrumbs_checked_nodes'),
  );
  $form['#redirect'] = FALSE;

  return system_settings_form($form);
}

/**
 * Removes all entries in disable_breadcrumbs table.
 */
function disable_breadcrumbs_settings_form_delete_all_submit() {
  db_query("DELETE FROM {disable_breadcrumbs}");
  drupal_set_message(t("The disable_breadcrumbs database table has been cleared."));
}

/**
 * Produce sortable table of currently checked nodes
 */
function theme_disable_breadcrumbs_checked_nodes() {
  $header = array(
    array(
      'data' => 'Node (nid)',
      'field' => 'n.nid',
      'sort' => 'desc',
      ), 
    array(
      'data' => 'Type',
      'field' => 'n.type',
      ),
    array(
      'data' => 'Title',
      'field' => 'n.title',
      ),
    'Operations',
  );

  $query = db_select('node', 'n')->extend('tableSort')->orderByHeader($header);
    $query->fields('n', array('nid', 'type', 'title'));
    $query->innerJoin('disable_breadcrumbs', 'db', 'n.nid = db.nid');

  $result = $query->execute();

  $rows = array();
  foreach ($result as $row) {
    $rows[$row->nid] = array(
      $row->nid,
      $row->type,
      l($row->title, 'node/' . $row->nid),
      '<a href="' . base_path() . 'node/' . $row->nid . '/edit' . '">Edit</a>',
    );
  }

  $table = array(
    'header' => $header,
    'rows' => $rows,
  );

  $output = theme('table', $table);

  return $output;
}
